@@ -3,7 +3,7 @@ import inspect
 from dataclasses import dataclass, field
 from typing import Any, Iterator, List, Optional
 
-from mkapi.core.base import Base
+from mkapi.core.base import Base, Type
 from mkapi.core.object import from_object, get_object, get_sourcefiles
 from mkapi.core.structure import Object, Tree
 
@@ -38,9 +38,10 @@ class Node(Tree):
         self.members = [m for m in members if m.object.name != "__init__"]
         if self.docstring and self.docstring.type:
             self.object.type = self.docstring.type
+            self.docstring.type = Type()
 
     def __iter__(self) -> Iterator[Base]:
-        yield self.object
+        yield from self.object
         yield from self.docstring
         for member in self.members:
             yield from member
@@ -185,7 +186,7 @@ def get_members(obj: Any) -> List[Node]:
     return sorted(members, key=lambda x: (-x.sourcefile_index, x.lineno))
 
 
-def get_node(name, sourcefile_index: int = 0, use_cache: bool = True) -> Node:
+def get_node(name, sourcefile_index: int = 0) -> Node:
     """Returns a Node instace by name or object.
 
     Args:
@@ -193,6 +194,16 @@ def get_node(name, sourcefile_index: int = 0, use_cache: bool = True) -> Node:
         sourcefile_index: If `obj` is a member of class, this value is the index of
             unique source files given by `mro()` of the class. Otherwise, 0.
     """
+
+    if isinstance(name, str):
+        obj = get_object(name)
+    else:
+        obj = name
+
+    return Node(obj, sourcefile_index)
+
+
+def get_node_from_module(name):
     from mkapi.core.module import modules
 
     if isinstance(name, str):
@@ -200,10 +211,4 @@ def get_node(name, sourcefile_index: int = 0, use_cache: bool = True) -> Node:
     else:
         obj = name
 
-    if use_cache:
-        if hasattr(obj, "__module__") and obj.__module__ in modules:
-            node = modules[obj.__module__]
-            if obj.__qualname__ in node:
-                return node[obj.__qualname__]
-
-    return Node(obj, sourcefile_index)
+    return modules[obj.__module__].node[obj.__qualname__]
